.. expect: role missing closing backtick: ':class:`foo but no other issues,\nand there is other lines too.\n' (missing-backtick-after-role)

In this paragraph there is a missing
backtick at the end of a role,
:class:`foo but no other issues,
and there is other lines too.
